@@ -14,7 +14,7 @@ import pandas as pd
 from Bio.Data.IUPACData import protein_letters_1to3
 from Bio.PDB.DSSP import dssp_dict_from_pdb_file, residue_max_acc
 
-from graphein.protein.utils import download_pdb
+from graphein.protein.utils import download_pdb, is_tool
 
 DSSP_COLS = [
     "chain",
@@ -109,7 +109,13 @@ def add_dssp_df(G: nx.Graph, dssp_config: Optional[DSSPConfig]) -> nx.Graph:
     config = G.graph["config"]
     pdb_id = G.graph["pdb_id"]
 
-    # TODO - Check for DSSP installation
+    # Extract DSSP executable
+    executable = dssp_config.executable
+
+    # Ensure that DSSP is on PATH and is marked as an executable.
+    assert is_tool(
+        executable
+    ), "DSSP must be on PATH and marked as an executable"
 
     # Check for existence of pdb file. If not, download it.
     if not os.path.isfile(config.pdb_dir / pdb_id):
@@ -117,9 +123,6 @@ def add_dssp_df(G: nx.Graph, dssp_config: Optional[DSSPConfig]) -> nx.Graph:
     else:
         pdb_file = config.pdb_dir + pdb_id + ".pdb"
 
-    # Extract DSSP executable
-    executable = dssp_config.executable
-
     if config.verbose:
         print(f"Using DSSP executable '{executable}'")
 
@@ -173,7 +176,7 @@ def add_dssp_feature(G: nx.Graph, feature: str) -> nx.Graph:
     config = G.graph["config"]
     dssp_df = G.graph["dssp_df"]
 
-    # Change to not allow for atom granuarlity?
+    # Change to not allow for atom granularity?
     if config.granularity == "atom":
         # TODO confirm below is not needed and remove
         """
